#!/usr/bin/perl
#
# autors:
# 	Przemyslaw Iskra <sparky@pld-linux.org>
# 	Karol Krenski <mimooh@inf.sgsp.edu.pl>
#
# both image and script may be distributed and modified
# under the terms of the GNU General Public License v2
#
# Version: 2
use strict;
use warnings;

my $theme = "ppcrcd";
my $imgdir = "/etc/splash/$theme/images";
my %points = (	# for 1024x768
	x1 => 54,
	y1 => 160,
	x2 => 982,
	y2 => 704
);

my @resolutions = (
	"640x480",	# standart vga
	"800x600",	# standart vga
	"1024x768",	# standart vga
	"1280x854",
	"1280x1024",	# standart lcd 5:4
	"1440x960",	# PowerBook 17"
	"1400x1050",
	"1600x1200",	# vga
);
my @more_res = (	# not common resolutions
	"1152x864",
	"1280x768",
	"1280x800",
	"1280x960",
	"1440x900",
	"1680x1050",
	"1920x1200",
);



my $pic = shift @ARGV || die "no picture specified\n";
my $scale = shift @ARGV || 0;
(my $picname = $pic) =~ s#.*/##;
my @conv_opts;
while ($#ARGV > 0) {
	my $opt = shift @ARGV;
	if ($opt eq "--") {
		@conv_opts = @ARGV;
		last;
	} else {
		warn "Option $opt ignored\n";
	}
}

push @resolutions, @more_res unless $scale;

system "mkdir -p $theme/images";
unless ($scale) {
	system "cp $pic $theme/images";
}

for my $res (@resolutions) {
	$res =~ /^([0-9]+)x([0-9]+)$/;
	my ($rw, $rh) = ($1, $2);

	my $tx = $rw * $points{x1} / 1024;
	my $ty = $rh * $points{y1} / 768;
	my $tw = int ( $rw * $points{x2} / 1024 - $tx);
	my $th = int ( $rh * $points{y2} / 768 - $ty);
	$tx = int $tx;
	$ty = int $ty;

	if ($scale) {
		$picname = "$theme-$res.jpg";
		system qw(convert -resize), $res."!", @conv_opts, $pic, "$theme/images/$picname";
	}

	open F_OUT, "> $theme/$res.cfg";
	print F_OUT <<EOF;
#
# Bootsplash configuration file for 
# theme $theme, resolution $res.
#
# autors:
# 	Przemyslaw Iskra <sparky\@pld-linux.org>
# 	Karol Krenski <mimooh\@inf.sgsp.edu.pl>
#
# both image and script may be distributed and modified
# under the terms of the GNU General Public License v2
#
# Version: 2

# bgcolor is the text background (i.e. transparent) color.
bgcolor=0

# (tx, ty) are the (x, y) coordinates of the text window in pixels.
# tw/th is the width/height of the text window in pixels.
tx=$tx
ty=$ty
tw=$tw
th=$th

# name of the picture file (full path recommended)
pic=$imgdir/$picname
# no silentpic, use the same
silentpic=$imgdir/$picname

EOF
	close F_OUT;

}
